package com.ruoyi.bst.order.service.impl;

import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.service.OrderAssembler;
import com.ruoyi.bst.orderProd.domain.OrderProdQuery;
import com.ruoyi.bst.orderProd.domain.OrderProdVO;
import com.ruoyi.bst.orderProd.service.IOrderProdService;
import com.ruoyi.bst.orderProd.service.OrderProdAssembler;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/12/18
 */
@Service
public class OrderAssemblerImpl implements OrderAssembler {

    @Autowired
    private IOrderProdService orderProdService;

    @Autowired
    private OrderProdAssembler orderProdAssembler;

    @Override
    public void assembleProdList(List<OrderVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        // 查询列表
        OrderProdQuery query = new OrderProdQuery();
        query.setOrderIds(CollectionUtils.map(list, OrderVO::getId));
        List<OrderProdVO> prodList = orderProdService.selectOrderProdList(query);

        // 分组
        Map<Long, List<OrderProdVO>> group = prodList.stream().collect(Collectors.groupingBy(OrderProdVO::getOrderId));

        // 拼接
        for (OrderVO vo : list) {
            List<OrderProdVO> productList = group.get(vo.getId());
            if (productList == null) {
                productList = new ArrayList<>();
            }
            vo.setProdList(productList);
        }
    }

    @Override
    public void assembleProdProcessList(List<OrderVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        List<OrderProdVO> prodList = list.stream().map(OrderVO::getProdList).flatMap(List::stream).collect(Collectors.toList());
        orderProdAssembler.assembleProcessList(prodList);
    }

    @Override
    public void assembleVO(List<OrderVO> list) {
        this.assembleProdList(list);
        this.assembleProdProcessList(list);
        this.assembleProgress(list);
    }

    @Override
    public void assembleProgress(List<OrderVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        List<OrderProdVO> prodList = list.stream().map(OrderVO::getProdList).flatMap(List::stream).collect(Collectors.toList());
        orderProdAssembler.assembleProgress(prodList);

        for (OrderVO order : list) {
            order.setTotalNum(CollectionUtils.sumDecimal(order.getProdList(), OrderProdVO::getNum));
            order.setReportNum(CollectionUtils.sumDecimal(order.getProdList(), OrderProdVO::getReportNum));
            order.setStoreNum(CollectionUtils.sumDecimal(order.getProdList(), OrderProdVO::getStoreNum));

            // 成品
            OrderProdVO endProd = order.getProdList().stream()
                    .filter(item -> item.getIsEnd() != null && item.getIsEnd())
                    .findFirst()
                    .orElse(null);
            if (endProd != null) {
                order.setEndReportNum(endProd.getReportNum());
                order.setEndStoreNum(endProd.getStoreNum());
            } else {
                order.setEndReportNum(BigDecimal.ZERO);
                order.setEndStoreNum(BigDecimal.ZERO);
            }
        }
    }
}
