package com.ruoyi.bst.orderProd.service.impl;

import com.ruoyi.bst.orderProd.domain.OrderProdBO;
import com.ruoyi.bst.orderProd.service.OrderProdConverter;
import com.ruoyi.bst.prodProcess.domain.ProdProcessBO;
import com.ruoyi.bst.prodProcess.service.ProdProcessAssembler;
import com.ruoyi.bst.prodProcess.service.ProdProcessConverter;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/12/17
 */
@Service
public class OrderProdConverterImpl implements OrderProdConverter {

    @Autowired
    private ProdProcessConverter prodProcessConverter;

    @Autowired
    private ProdProcessAssembler prodProcessAssembler;

    @Override
    public List<OrderProdBO> toBOListByCreate(List<OrderProdBO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return Collections.emptyList();
        }

        // 拼接部门信息
        List<ProdProcessBO> processList = list.stream().map(OrderProdBO::getProcessList)
                .filter(Objects::nonNull)
                .flatMap(List::stream).collect(Collectors.toList());
        prodProcessAssembler.assembleDept(processList);

        List<OrderProdBO> boList = new ArrayList<>();
        for (OrderProdBO prod : list) {
            OrderProdBO bo = new OrderProdBO();
            bo.setWorkType(prod.getWorkType());
            bo.setIsEnd(prod.getIsEnd());
            bo.setMaterialNo(prod.getMaterialNo());
            bo.setPicture(prod.getPicture());
            bo.setName(prod.getName());
            bo.setSpec(prod.getSpec());
            bo.setNum(prod.getNum());
            bo.setRemark(prod.getRemark());
            bo.setSort(prod.getSort());
            bo.setHandleWay(prod.getHandleWay());
            bo.setEffect(prod.getEffect());
            bo.setColor(prod.getColor());
            bo.setCoverColor(prod.getCoverColor());
            bo.setContentNum(prod.getContentNum());
            bo.setNo(prod.getNo());
            bo.setWorkName(prod.getWorkName());
            bo.setContractNo(prod.getContractNo());
            bo.setProcessList(prodProcessConverter.toBOListByCreate(prod.getProcessList()));

            boList.add(bo);
        }
        return boList;
    }

    @Override
    public List<OrderProdBO> toBOListByUpdate(List<OrderProdBO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return Collections.emptyList();
        }

        // 拼接部门信息
        List<ProdProcessBO> processList = list.stream().map(OrderProdBO::getProcessList)
                .filter(Objects::nonNull)
                .flatMap(List::stream).collect(Collectors.toList());
        prodProcessAssembler.assembleDept(processList);

        List<OrderProdBO> boList = new ArrayList<>();
        for (OrderProdBO prod : list) {
            OrderProdBO bo = new OrderProdBO();
            bo.setId(prod.getId());
            bo.setWorkType(prod.getWorkType());
            bo.setIsEnd(prod.getIsEnd());
            bo.setMaterialNo(prod.getMaterialNo());
            bo.setPicture(prod.getPicture());
            bo.setName(prod.getName());
            bo.setSpec(prod.getSpec());
            bo.setNum(prod.getNum());
            bo.setRemark(prod.getRemark());
            bo.setSort(prod.getSort());
            bo.setHandleWay(prod.getHandleWay());
            bo.setEffect(prod.getEffect());
            bo.setColor(prod.getColor());
            bo.setCoverColor(prod.getCoverColor());
            bo.setContentNum(prod.getContentNum());
            bo.setNo(prod.getNo());
            bo.setWorkName(prod.getWorkName());
            bo.setContractNo(prod.getContractNo());
            bo.setProcessList(prodProcessConverter.toBOListByUpdate(prod.getProcessList()));

            boList.add(bo);
        }
        return boList;
    }
}
