package com.ruoyi.bst.orderProd.service.impl;

import com.ruoyi.bst.orderProd.domain.OrderProd;
import com.ruoyi.bst.orderProd.domain.OrderProdQuery;
import com.ruoyi.bst.orderProd.domain.OrderProdVO;
import com.ruoyi.bst.orderProd.mapper.OrderProdMapper;
import com.ruoyi.bst.orderProd.service.IOrderProdService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.support.TransactionTemplate;

import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * 订单产品Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-17
 */
@Service
public class OrderProdServiceImpl implements IOrderProdService
{
    @Autowired
    private OrderProdMapper orderProdMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    /**
     * 查询订单产品
     *
     * @param id 订单产品主键
     * @return 订单产品
     */
    @Override
    public OrderProdVO selectOrderProdById(Long id)
    {
        return orderProdMapper.selectOrderProdById(id);
    }

    /**
     * 查询订单产品列表
     *
     * @param orderProd 订单产品
     * @return 订单产品
     */
    @Override
    public List<OrderProdVO> selectOrderProdList(OrderProdQuery orderProd)
    {
        return orderProdMapper.selectOrderProdList(orderProd);
    }

    /**
     * 新增订单产品
     *
     * @param orderProd 订单产品
     * @return 结果
     */
    @Override
    public int insertOrderProd(OrderProd orderProd)
    {
        orderProd.setCreateTime(DateUtils.getNowDate());
        return orderProdMapper.insertOrderProd(orderProd);
    }

    /**
     * 修改订单产品
     *
     * @param orderProd 订单产品
     * @return 结果
     */
    @Override
    public int updateOrderProd(OrderProd orderProd)
    {
        return orderProdMapper.updateOrderProd(orderProd);
    }

    /**
     * 批量删除订单产品
     *
     * @param ids 需要删除的订单产品主键
     * @return 结果
     */
    @Override
    public int deleteOrderProdByIds(Long[] ids)
    {
        return orderProdMapper.deleteOrderProdByIds(ids);
    }

    /**
     * 删除订单产品信息
     *
     * @param id 订单产品主键
     * @return 结果
     */
    @Override
    public int deleteOrderProdById(Long id)
    {
        return orderProdMapper.deleteOrderProdById(id);
    }

    @Override
    public List<OrderProdVO> selectByOrderId(Long orderId) {
        if (orderId == null) {
            return Collections.emptyList();
        }
        OrderProdQuery query = new OrderProdQuery();
        query.setOrderId(orderId);
        return this.selectOrderProdList(query);
    }

    @Override
    public int batchInsert(List<? extends OrderProd> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        Date now = DateUtils.getNowDate();
        for (OrderProd prod : list) {
            prod.setCreateTime(now);
        }
        return orderProdMapper.batchInsert(list);
    }

    @Override
    public int batchUpdate(List<? extends OrderProd> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return orderProdMapper.batchUpdate(list);
    }

    @Override
    public int batchLogicDel(List<? extends OrderProd> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return orderProdMapper.logicDel(CollectionUtils.map(list, OrderProd::getId));
    }

    @Override
    public int logicDelByOrderId(Long orderId) {
        if (orderId == null) {
            return 0;
        }
        return orderProdMapper.logicDelByOrderId(orderId);
    }

    @Override
    public List<String> selectNameList(OrderProdQuery query) {
        return orderProdMapper.selectNameList(query); // 新增的方法实现
    }
}
