package com.ruoyi.bst.prodProcess.service.impl;

import com.ruoyi.bst.prodProcess.domain.ProdProcess;
import com.ruoyi.bst.prodProcess.domain.ProdProcessBO;
import com.ruoyi.bst.prodProcess.domain.ProdProcessQuery;
import com.ruoyi.bst.prodProcess.domain.ProdProcessVO;
import com.ruoyi.bst.prodProcess.domain.vo.ProdProcessNameVO;
import com.ruoyi.bst.prodProcess.service.IProdProcessService;
import com.ruoyi.bst.prodProcess.service.ProdProcessAssembler;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.store.domain.enums.StoreGroupBy;
import com.ruoyi.bst.store.domain.enums.StoreStatus;
import com.ruoyi.bst.store.service.IStoreService;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.LongDecimalVO;
import com.ruoyi.system.dept.domain.SysDeptQuery;
import com.ruoyi.system.dept.domain.SysDeptVO;
import com.ruoyi.system.dept.service.ISysDeptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/12/20
 */
@Service
public class ProdProcessAssemblerImpl implements ProdProcessAssembler {
    @Autowired
    private ISysDeptService deptService;

    @Autowired
    private IStoreService storeService;

    @Autowired
    private IProdProcessService prodProcessService;

    @Override
    public void assembleDept(List<ProdProcessBO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        SysDeptQuery query = new SysDeptQuery();
        query.setDeptIds(CollectionUtils.map(list, ProdProcess::getDeptId));
        List<SysDeptVO> deptList = deptService.selectDeptList(query);

        for (ProdProcessBO process : list) {
            SysDeptVO dept = deptList.stream().filter(item -> Objects.equals(item.getDeptId(), process.getDeptId())).findFirst().orElse(null);
            if (dept != null) {
                process.setDeptProcess(dept.getProcess());
            }
        }

    }

    @Override
    public void assembleReportNum(List<ProdProcessVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return ;
        }

        StoreQuery query = new StoreQuery();
        query.setProcessIds(CollectionUtils.map(list, ProdProcessVO::getId));
        List<LongDecimalVO> groups = storeService.selectSumOfNumGroupByLong(query, StoreGroupBy.PROCESS_ID);

        for (ProdProcessVO process : list) {
            LongDecimalVO vo = groups.stream().filter(item -> Objects.equals(item.getKey(), process.getId())).findFirst().orElse(null);
            if (vo == null) {
                process.setReportNum(BigDecimal.ZERO);
            } else {
                process.setReportNum(vo.getValue());
            }
        }
    }

    @Override
    public void assembleStoreNum(List<ProdProcessVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return ;
        }

        StoreQuery query = new StoreQuery();
        query.setProcessIds(CollectionUtils.map(list, ProdProcessVO::getId));
        query.setStatus(StoreStatus.STORED.getStatus());
        List<LongDecimalVO> groups = storeService.selectSumOfStoreNumGroupByLong(query, StoreGroupBy.PROCESS_ID);

        for (ProdProcessVO process : list) {
            LongDecimalVO vo = groups.stream().filter(item -> Objects.equals(item.getKey(), process.getId())).findFirst().orElse(null);
            if (vo == null) {
                process.setStoreNum(BigDecimal.ZERO);
            } else {
                process.setStoreNum(vo.getValue());
            }
        }
    }

    @Override
    public void assembleProgress(List<ProdProcessVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        this.assembleReportNum(list);
        this.assembleStoreNum(list);
    }

    @Override
    public void assembleProdList(List<ProdProcessNameVO> list, ProdProcessQuery query) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        // 查询列表
        query.setEqNames(CollectionUtils.map(list, ProdProcessNameVO::getName));
        List<ProdProcessVO> prodList = prodProcessService.selectProdProcessList(query);
        // 拼接进度
        this.assembleProgress(prodList);
        // 分组
        Map<String, List<ProdProcessVO>> group = prodList.stream().collect(Collectors.groupingBy(ProdProcessVO::getOrderProdName));

        // 组装数据
        for (ProdProcessNameVO vo : list) {
            List<ProdProcessVO> groupList = group.get(vo.getName());
            if (groupList == null) {
                groupList = new ArrayList<>();
            }
            vo.setProcessList(groupList);
        }

    }

    @Override
    public void assembleTotalNum(List<ProdProcessNameVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        for (ProdProcessNameVO vo : list) {
            List<ProdProcessVO> processList = vo.getProcessList();
            if (CollectionUtils.isEmptyElement(processList)) {
                continue;
            }
            vo.setTotalNum(CollectionUtils.sumDecimal(processList, ProdProcessVO::getNum));
            vo.setReportNum(CollectionUtils.sumDecimal(processList, ProdProcessVO::getReportNum));
            vo.setStoreNum(CollectionUtils.sumDecimal(processList, ProdProcessVO::getStoreNum));
        }
    }
}
