package com.ruoyi.bst.store.domain;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.constant.DictType;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.ValidGroup;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.math.BigDecimal;
import java.sql.Date;
import java.time.LocalDateTime;

/**
 * 入库对象 bst_store
 *
 * @author ruoyi
 * @date 2024-12-19
 */
@Data
public class Store extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    @Excel(name = "ID", type = Excel.Type.EXPORT, sort = 1)
    private Long id;

    @ApiModelProperty("工序ID")
    @NotNull(message = "工序不允许为空", groups = {ValidGroup.Create.class})
    private Long processId;

    @Excel(name = "上报数量", sort = 7)
    @ApiModelProperty("上报数量")
    @NotNull(message = "上报数量不允许为空", groups = {ValidGroup.Create.class})
    @Min(value = 1, message = "上报数量不能小于1")
    private BigDecimal num;

    @Excel(name = "清点数量", sort = 8)
    @ApiModelProperty("清点数量")
    private BigDecimal storeNum;

    @ApiModelProperty("上报人ID")
    private Long createId;

    @Excel(name = "上报人", sort = 9)
    @ApiModelProperty("上报人")
    private String createBy;

    @Excel(name = "状态", dictType = DictType.STORE_STATUS, comboReadDict = true, sort = 6)
    @ApiModelProperty("状态")
    private String status;

    @ApiModelProperty("入库人ID")
    private Long storeUserId;

    @Excel(name = "清点人", sort = 12)
    @ApiModelProperty("清点人")
    private String storeBy;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "清点时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss", sort = 13)
    @ApiModelProperty("清点时间")
    private LocalDateTime storeTime;

    @Excel(name = "备注", sort = 11)
    @Size(max = 200, message = "备注长度不能超过200个字符")
    private String remark;

    @Excel(name = "上报时间", width = 30, dateFormat = "yyyy-MM-dd", sort = 10)
    @ApiModelProperty("上报时间")
    private Date createTime;

    public Date getCreateTime() {
        return this.createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }
}
