package com.ruoyi.bst.store.mapper;

import com.ruoyi.bst.store.domain.Store;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.store.domain.StoreVO;
import com.ruoyi.common.vo.LongDecimalVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 入库Mapper接口
 *
 * @author ruoyi
 * @date 2024-12-19
 */
public interface StoreMapper
{
    /**
     * 查询入库
     *
     * @param id 入库主键
     * @return 入库
     */
    StoreVO selectStoreById(Long id);

    /**
     * 查询入库列表
     *
     * @param query 入库
     * @return 入库集合
     */
    List<StoreVO> selectStoreList(@Param("query")StoreQuery query);

    /**
     * 新增入库
     *
     * @param store 入库
     * @return 结果
     */
    int insertStore(Store store);

    /**
     * 修改入库
     *
     * @param store 入库
     * @return 结果
     */
    public int updateStore(@Param("data") Store store);

    /**
     * 删除入库
     *
     * @param id 入库主键
     * @return 结果
     */
    int deleteStoreById(Long id);

    /**
     * 批量删除入库
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteStoreByIds(Long[] ids);

    int updateByQuery(@Param("data") Store data, @Param("query") StoreQuery query);

    /**
     * 查询上报数量之和
     */
    List<LongDecimalVO> selectSumOfNumGroupByLong(@Param("query") StoreQuery query, @Param("groupBy") String groupBy);

    /**
     * 查询入库数量之和
     */
    List<LongDecimalVO> selectSumOfStoreNumGroupByLong(@Param("query") StoreQuery query, @Param("groupBy") String groupBy);

}
