package com.ruoyi.bst.store.service;

import com.ruoyi.bst.store.domain.Store;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.store.domain.StoreVO;
import com.ruoyi.bst.store.domain.enums.StoreGroupBy;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.vo.LongDecimalVO;

import java.math.BigDecimal;
import java.util.List;

/**
 * 入库Service接口
 *
 * @author ruoyi
 * @date 2024-12-19
 */
public interface IStoreService
{
    /**
     * 查询入库
     *
     * @param id 入库主键
     * @return 入库
     */
    public StoreVO selectStoreById(Long id);

    /**
     * 查询入库列表
     *
     * @param store 入库
     * @return 入库集合
     */
    public List<StoreVO> selectStoreList(StoreQuery store);

    /**
     * 新增入库
     *
     * @param store 入库
     * @return 结果
     */
    public int insertStore(Store store);

    /**
     * 修改入库
     *
     * @param store 入库
     * @return 结果
     */
    public int updateStore(Store store);

    /**
     * 批量删除入库
     *
     * @param ids 需要删除的入库主键集合
     * @return 结果
     */
    public int deleteStoreByIds(Long[] ids);

    /**
     * 删除入库信息
     *
     * @param id 入库主键
     * @return 结果
     */
    public int deleteStoreById(Long id);

    /**
     * 删除入库
     */
    int logicDel(Long id);

    /**
     * 入库操作
     * @param id 入库ID
     * @param storeNum 入库数量
     * @param user 操作人
     */
    int stockIn(Long id, BigDecimal storeNum, SysUser user);

    /**
     * 查询上报数量总和
     */
    List<LongDecimalVO> selectSumOfNumGroupByLong(StoreQuery query, StoreGroupBy groupBy);

    /**
     * 查询入库数量总和
     */
    List<LongDecimalVO> selectSumOfStoreNumGroupByLong(StoreQuery query, StoreGroupBy groupBy);

}
